package com.gprinter.utils;

import android.graphics.Bitmap;
import android.graphics.pdf.PdfRenderer;
import android.os.ParcelFileDescriptor;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.UnsupportedEncodingException;

/* loaded from: com_gprinter_utils.jar:com/gprinter/utils/PDFUtils.class */
public class PDFUtils {
    public static Bitmap[] PDFToBitmap(File file, int width) throws Exception {
        if (file == null) {
            new Exception("File no exit");
            return null;
        }
        ParcelFileDescriptor mFileDescriptor = null;
        PdfRenderer.Page mCurrentPage = null;
        try {
            try {
                mFileDescriptor = ParcelFileDescriptor.open(file, 268435456);
                mPdfRenderer = mFileDescriptor != null ? new PdfRenderer(mFileDescriptor) : null;
                int pageCount = mPdfRenderer.getPageCount();
                Bitmap[] bitmaps = new Bitmap[pageCount];
                for (int i = 0; i < pageCount; i++) {
                    if (mCurrentPage != null) {
                        mCurrentPage.close();
                    }
                    mCurrentPage = mPdfRenderer.openPage(i);
                    int scaleWidth = ((width + 7) / 8) * 8;
                    int scaleHeight = (mCurrentPage.getHeight() * scaleWidth) / mCurrentPage.getWidth();
                    Bitmap bitmap = Bitmap.createBitmap(scaleWidth, scaleHeight, Bitmap.Config.ARGB_8888);
                    bitmap.eraseColor(-1);
                    mCurrentPage.render(bitmap, null, null, 2);
                    bitmaps[i] = bitmap;
                }
                if (null != mCurrentPage) {
                    mCurrentPage.close();
                }
                if (mPdfRenderer != null) {
                    mPdfRenderer.close();
                }
                try {
                    mFileDescriptor.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                return bitmaps;
            } catch (Throwable th) {
                if (null != mCurrentPage) {
                    mCurrentPage.close();
                }
                if (mPdfRenderer != null) {
                    mPdfRenderer.close();
                }
                try {
                    mFileDescriptor.close();
                } catch (IOException e2) {
                    e2.printStackTrace();
                }
                throw th;
            }
        } catch (FileNotFoundException e3) {
            new Exception("File no exit");
            if (null != mCurrentPage) {
                mCurrentPage.close();
            }
            if (mPdfRenderer != null) {
                mPdfRenderer.close();
            }
            try {
                mFileDescriptor.close();
            } catch (IOException e4) {
                e4.printStackTrace();
            }
            return null;
        } catch (IOException e5) {
            new Exception("Parsing File no error");
            if (null != mCurrentPage) {
                mCurrentPage.close();
            }
            if (mPdfRenderer != null) {
                mPdfRenderer.close();
            }
            try {
                mFileDescriptor.close();
            } catch (IOException e6) {
                e6.printStackTrace();
            }
            return null;
        }
    }

    public static byte[] drawEscPDF(Bitmap bitmap) {
        int width1;
        int bmpWidth = bitmap.getWidth() % 8;
        if (bmpWidth == 0) {
            width1 = bitmap.getWidth() / 8;
        } else {
            width1 = (bitmap.getWidth() / 8) + 1;
        }
        int bmpHeight = bitmap.getHeight();
        byte[] printImage = BitmapUtils.getCompressedBinaryzationBytes(bitmap, 190, true);
        byte[] data = new byte[printImage.length + 8];
        data[0] = 29;
        data[1] = 118;
        data[2] = 48;
        data[3] = 0;
        data[4] = (byte) (width1 % 256);
        data[5] = (byte) (width1 / 256);
        data[6] = (byte) (bmpHeight % 256);
        data[7] = (byte) (bmpHeight / 256);
        for (int i = 0; i < printImage.length; i++) {
            data[i + 8] = printImage[i];
        }
        return data;
    }

    public static byte[] drawTscPDF(Bitmap bitmap) throws UnsupportedEncodingException {
        int width = bitmap.getWidth() % 8 == 0 ? bitmap.getWidth() / 8 : (bitmap.getWidth() / 8) + 1;
        int height = bitmap.getHeight();
        String bitmapCmd = "BITMAP 0,0," + width + "," + height + ",0,";
        byte[] data = BitmapUtils.getCompressedBinaryzationBytes(bitmap, 190, false);
        int x1 = bitmap.getWidth() % 8;
        if (x1 != 0) {
            int i = 0;
            while (true) {
                int x3 = i;
                if (x3 >= data.length) {
                    break;
                }
                int i2 = (x3 + width) - 1;
                data[i2] = (byte) (data[i2] | ((byte) (255 >> x1)));
                i = x3 + width;
            }
        }
        return addBytes(bitmapCmd.getBytes("GB18030"), data);
    }

    public static byte[] drawTscPDFLib(Bitmap bitmap) throws UnsupportedEncodingException {
        int width = bitmap.getWidth() % 8 == 0 ? bitmap.getWidth() / 8 : (bitmap.getWidth() / 8) + 1;
        int height = bitmap.getHeight();
        byte[] data = BitmapUtils.getCompressedBinaryzationBytes(bitmap, 128, true);
        int x1 = bitmap.getWidth() % 8;
        if (x1 != 0) {
            int i = 0;
            while (true) {
                int x3 = i;
                if (x3 >= data.length) {
                    break;
                }
                int i2 = (x3 + width) - 1;
                data[i2] = (byte) (data[i2] | ((byte) (255 >> x1)));
                i = x3 + width;
            }
        }
        byte[] compressByte = new byte[0];
        try {
            compressByte = ZLibUtils.zLib(data, 9);
        } catch (IOException var7) {
            var7.printStackTrace();
        }
        String bitmapCmd = "BITMAP 0,0," + width + "," + height + ",3," + compressByte.length + ",";
        return addBytes(bitmapCmd.getBytes("GB18030"), compressByte);
    }

    public static byte[] addBytes(byte[] data1, byte[] data2) {
        byte[] data3 = new byte[data1.length + data2.length];
        System.arraycopy(data1, 0, data3, 0, data1.length);
        System.arraycopy(data2, 0, data3, data1.length, data2.length);
        return data3;
    }
}
